@@ -1,5 +1,5 @@
 # Django
-from django.apps import apps
+from django.apps import apps as django_apps
 from django.core.exceptions import ImproperlyConfigured
 
 # SquareletAuth
@@ -11,7 +11,7 @@ def get_organization_model():
     Return the Organization model that is active in this project.
     """
     try:
-        return apps.get_model(settings.ORGANIZATION_MODEL, require_ready=False)
+        return django_apps.get_model(settings.ORGANIZATION_MODEL, require_ready=False)
     except ValueError:
         raise ImproperlyConfigured(
             "SQUARELET_ORGANIZATION_MODEL must be of the form 'app_label.model_name'"
